/* File name: storage.c
 * Author: Pedro Castro
 * Date: October 2023
 * Description: Functions to store in flash some values
 */
#include <zephyr/zephyr.h>
#include <zephyr/settings/settings.h>

#include "storage.h"
#include "../cfg/config.h"

struct nvs_store nvs_store = {
    .ble_name = DEF_BLE_NAME
};

static int settings_set(const char *name, size_t len, settings_read_cb read_cb, void *cb_arg) {
	const char *next;
	int rc;

	if (settings_name_steq(name, "ble_name", &next) && !next) {
		if (len != sizeof(nvs_store.ble_name)) {
			return -EINVAL;
		}

		rc = read_cb(cb_arg, &nvs_store.ble_name, sizeof(nvs_store.ble_name));
		if (rc >= 0) {
			return 0;
		}

		return rc;
	}

	return -ENOENT;
}

int storage_save_all( void ) {
    settings_save_one("app/ble_name", &nvs_store.ble_name, sizeof(nvs_store.ble_name));

    return 0;
}

int storage_init( void ) {
   	static struct settings_handler conf = {
		.name = "app",
		.h_set = settings_set
	};

    settings_register(&conf);

    return 0;
}